Enum SessionState Copy item path Source #[repr(i32)]
pub enum SessionState {
Unspecified = 0,
Open = 1,
Resolved = 2,
Expired = 3,
Suspended = 4,
Cancelled = 5,
}Session paused by an accepted SuspendSession RPC (RFC-MACP-0001 7.5).
Non-terminal: TTL is banked while suspended and restored on ResumeSession.
Only OPEN<->SUSPENDED and SUSPENDED->EXPIRED transitions are permitted; a
commitment may only be emitted from OPEN, so SUSPENDED->RESOLVED is not.
Terminal state for a session ended by an accepted CancelSession RPC
(RFC-MACP-0001 7.3). Distinct from EXPIRED (TTL / deterministic runtime
policy) so consumers can tell explicit cancellation from expiry.
Returns true if value is a variant of SessionState.
👎 Deprecated: Use the TryFrom<i32> implementation instead
Converts an i32 to a SessionState, or None if value is not a valid variant.
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable
(if the ProtoBuf definition does not change) and safe for programmatic use.
Creates an enum from field names used in the ProtoBuf definition.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Converts to this type from the input type.
Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more 🔬 This is a nightly-only experimental API. (clamp_to)
Restrict a value to a certain range.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.